function [exitFlag exitMsg netStruct] = fa_shortestPath_numLinks(netStruct, algorithmParameters, net2planParameters)

    % fa_shortestPath_numLinks
    %
    % Algorithm for flow assignment problems which tries to route all traffic
    % by the shortest path using 1 as cost per link.
    %
	% This algorithm has no specific parameters.
    
    try
        
        %% Sanity checks
        assert(isfield(netStruct, 'linkTable') && ~isempty(netStruct.linkTable), 'A link table is required');
        assert(isfield(netStruct, 'demandTable') && ~isempty(netStruct.demandTable), 'A demand set is required');
        
        %% Algorithm kernel
        E = size(netStruct.linkTable, 1);
        D = size(netStruct.demandTable, 1);
        P = D;
        
        x_dp = sparse(D, P);
        pathList = cell(1,P);
        
        for pathId = 1:P
		
			demandId = pathId;
			x_dp(demandId, pathId) = 1;
            
            ingressNodeId = netStruct.demandTable(demandId, 1);
            egressNodeId = netStruct.demandTable(demandId, 2);
            
            sequenceOfLinks = shortestPath(netStruct.linkTable, ones(1,E), ingressNodeId, egressNodeId);
            assert(~isempty(sequenceOfLinks), sprintf('No feasible path from %d to %d', ingressNodeId, egressNodeId));
            
            pathList{pathId} = sequenceOfLinks;
            
        end
        
        netStruct.pathList = pathList;
        netStruct.routingMatrix = x_dp;
		
        exitFlag = 0;
        exitMsg = 'OK!';
        
    catch e
        
        exitFlag = -1;
        exitMsg = e.message;
        netStruct = [];
        
    end

end